===========================
``filedb.filestore`` module
===========================

.. automodule:: whoosh.filedb.filestore

Base class
==========

.. autoclass:: Storage
    :members:


Implementation classes
======================

.. autoclass:: FileStorage
.. autoclass:: RamStorage


Helper functions
================

.. autofunction:: copy_storage
.. autofunction:: copy_to_ram


Exceptions
==========

.. autoexception:: ReadOnlyError
